==> lightspark-0.8.4.1.tar.gz: lightspark-0.8.4.1/src/scripting/flash/media/avnetworkingparams.h <==
/**************************************************************************
    Lightspark, a free flash player implementation

    Copyright (C) 2009-2013  Alessandro Pignotti (a.pignotti@sssup.it)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**************************************************************************/

#ifndef SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H
#define SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H 1

#include "asobject.h"

namespace lightspark
{

class AVNetworkingParams: public ASObject
{
public:
	AVNetworkingParams(Class_base* c):ASObject(c){}
	static void sinit(Class_base* c);
	ASFUNCTION_ATOM(_constructor);
	ASPROPERTY_GETTER_SETTER(tiny_string,appendRandomQueryParameter);
	ASPROPERTY_GETTER_SETTER(bool,forceNativeNetworking);
	ASPROPERTY_GETTER_SETTER(tiny_string,networkDownVerificationUrl);
	ASPROPERTY_GETTER_SETTER(bool,readSetCookieHeader);
	ASPROPERTY_GETTER_SETTER(bool,useCookieHeaderForAllRequests);
};

}
#endif /* SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H */

==> lightspark-0.9.0.tar.gz: lightspark-0.9.0/src/scripting/flash/media/avnetworkingparams.h <==
/**************************************************************************
    Lightspark, a free flash player implementation

    Copyright (C) 2009-2013  Alessandro Pignotti (a.pignotti@sssup.it)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
**************************************************************************/

#ifndef SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H
#define SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H 1

#include "asobject.h"

namespace lightspark
{

class AVNetworkingParams: public ASObject
{
public:
	AVNetworkingParams(ASWorker* wrk,Class_base* c):ASObject(wrk,c){}
	static void sinit(Class_base* c);
	ASFUNCTION_ATOM(_constructor);
	ASPROPERTY_GETTER_SETTER(tiny_string,appendRandomQueryParameter);
	ASPROPERTY_GETTER_SETTER(bool,forceNativeNetworking);
	ASPROPERTY_GETTER_SETTER(tiny_string,networkDownVerificationUrl);
	ASPROPERTY_GETTER_SETTER(bool,readSetCookieHeader);
	ASPROPERTY_GETTER_SETTER(bool,useCookieHeaderForAllRequests);
};

}
#endif /* SCRIPTING_FLASH_MEDIA_AVNETWORKINGPARAMS_H */
